Regisztráció Belépés

### Anya, bírd ki, később jobb lesz!

Katasztrofális a szülés utáni szexuális élet.

### A FIFA újraírja a szabályokat

Megszűnhet a játékosügynöki licenc.

### Apukateszt három gyerekkel

Három ördögfióka, rengeteg csomag és egy ázott földút várt a Suzuki S-Crossra.

Publikál Mégsem

#

# Blogajánlók

### Ice Ice Baby mindhalálig

Mit ettek ezen a klipen negyedszázada?

### Ismeretlen képek sztárokról

Ráadásul durván ki vannak varrva. Döbbenet.

### Garda-tavi kalandok bringával

Kulturális és kulináris élvezetek tekerés közben.

### Charlie búvárangyalai

Indokolt volt a film forgatásán a dublőrök használata.

# Címkék

bkv,utas,
Budapest,busz,
észrevétel,videó,
panasz,tévé,fotó,
metró,media,macska,kép,
berlet,villamos,vezető,
film,jegy,A világ érdekes,
ellenőr,bkvfigyelo,bwzene,
Még több címke